AdDimensions class

The on-screen size of a loaded view-based ad, in logical pixels.

Constructors

AdDimensions({required double width, required double height})
Creates dimensions of width x height.
const

Properties

hashCode int
The hash code for this object.
no setteroverride
height double
Height in logical pixels.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
width double
Width in logical pixels.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override