AdInspectorResult class

Result of opening the Ad Inspector.

Constructors

AdInspectorResult({AdFlowError? error})
Creates a result; error is null on success.
const

Properties

error AdFlowError?
The failure, if the inspector could not open or errored.
final
hashCode int
The hash code for this object.
no setterinherited
isSuccess bool
Whether the inspector opened and closed without error.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited