ConsentDebugOptions class

Debug settings for UMP consent testing. Remove before release.

Constructors

ConsentDebugOptions({ConsentDebugGeography geography = ConsentDebugGeography.disabled, List<String> testIdentifiers = const []})
Creates debug options.
const

Properties

geography ConsentDebugGeography
Simulated geography.
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
testIdentifiers List<String>
Hashed test device identifiers (printed to the console on first run).
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited