NativeLoadSpec class

Everything the seam needs to load one native ad.

Exactly one of templateKind (Dart template rendering) or factoryId (a platform-registered NativeAdFactory) must be provided.

Constructors

NativeLoadSpec({required String adUnitId, NativeTemplateKind? templateKind, String? factoryId, Map<String, Object>? factoryExtras, AdRequestOptions request = const AdRequestOptions()})
Creates a native load spec.
const

Properties

adUnitId String
The native ad unit.
final
factoryExtras Map<String, Object>?
Options passed through to a platform factory.
final
factoryId String?
Render with the platform-registered factory of this id.
final
hashCode int
The hash code for this object.
no setterinherited
request AdRequestOptions
Per-request options.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
templateKind NativeTemplateKind?
Render with a built-in template of this kind.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited