ConsentUpdateCall class

Constructors

ConsentUpdateCall({bool? tagForUnderAgeOfConsent, ConsentDebugOptions? debug})
Creates a record of the call's arguments.
const

Properties

debug ConsentDebugOptions?
The debug argument.
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
tagForUnderAgeOfConsent bool?
The tagForUnderAgeOfConsent argument.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited