consentUpdateHold property
If set, requestConsentInfoUpdate awaits this before completing — leave it incomplete to simulate a hanging network call.
Implementation
Completer<void>? consentUpdateHold;
If set, requestConsentInfoUpdate awaits this before completing — leave it incomplete to simulate a hanging network call.
Completer<void>? consentUpdateHold;