mediationInitDisabledBeforeInitialize property
Whether disableMediationInitialization was called before the first initialize — the only ordering in which the real plugin honours it.
Implementation
bool? mediationInitDisabledBeforeInitialize;
Whether disableMediationInitialization was called before the first initialize — the only ordering in which the real plugin honours it.
bool? mediationInitDisabledBeforeInitialize;