AdRequestConfig class
Global request configuration applied once via
MobileAds.updateRequestConfiguration's seam equivalent.
Constructors
-
AdRequestConfig({List<
String> ? testDeviceIds, MaxContentRating? maxAdContentRating, bool? tagForChildDirectedTreatment, bool? tagForUnderAgeOfConsent}) -
Creates a request configuration; all fields are optional.
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- maxAdContentRating → MaxContentRating?
-
Maximum content rating of served ads.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- tagForChildDirectedTreatment → bool?
-
COPPA tag;
nullmeans unspecified.final - tagForUnderAgeOfConsent → bool?
-
Tag users below the age of consent;
nullmeans unspecified.final -
testDeviceIds
→ List<
String> ? -
Device IDs that should always receive test ads.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited