PrivacyOptionsRequirement enum
Whether a privacy-options entry point must be surfaced in the app.
Values
- unknown → const PrivacyOptionsRequirement
-
Unknown (info update has not run).
- required → const PrivacyOptionsRequirement
-
A persistent "Manage consent" control is required.
- notRequired → const PrivacyOptionsRequirement
-
No privacy-options entry point is required.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
PrivacyOptionsRequirement> - A constant List of the values in this enum, in order of their declaration.