ServerSideVerification class
Server-side verification options for (rewarded) ads with high-value rewards — echoed back in AdMob's server-to-server reward callback.
Constructors
- ServerSideVerification({String? userId, String? customData})
-
Creates SSV options.
const
Properties
- customData → String?
-
Opaque data echoed back in the SSV callback.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- userId → String?
-
The user to credit in the SSV callback.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited