Google's official sample ad unit IDs (safe to click; used by AdFlowConfig.test and whenever AdFlowConfig.testMode is on).
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- appOpen → const PlatformAdUnitId
- Sample app open IDs.
- Sample banner IDs.
- interstitial → const PlatformAdUnitId
- Sample interstitial IDs.
- native → const PlatformAdUnitId
- Sample native (advanced) IDs.
- rewarded → const PlatformAdUnitId
- Sample rewarded IDs.
- rewardedInterstitial → const PlatformAdUnitId
- Sample rewarded interstitial IDs.